@@ -5,7 +5,7 @@ from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext, ugettext_lazy as _
 
 from mezzanine.core.fields import HtmlField
-from mezzanine.core.models import Orderable
+from mezzanine.core.models import Orderable, Content
 from mezzanine.forms.settings import FIELD_MAX_LENGTH, LABEL_MAX_LENGTH
 from mezzanine.pages.models import Page
 
@@ -27,7 +27,7 @@ FIELD_CHOICES = (
 )
 
 
-class Form(Page):
+class Form(Page, Content):
     """
     A user-built form.
     """
@@ -43,6 +43,8 @@ class Form(Page):
     email_copies = models.CharField(_("Send copies to"), blank=True,
         help_text=_("One or more email addresses, separated by commas"),
         max_length=200)
+    email_subject = models.CharField(_("Subject"), max_length=200, blank=True)
+    email_message = models.TextField(_("Message"), blank=True)
 
     class Meta:
         verbose_name = _("Form")
@@ -65,13 +67,14 @@ class Field(Orderable):
     form = models.ForeignKey("Form", related_name="fields")
     label = models.CharField(_("Label"), max_length=LABEL_MAX_LENGTH)
     field_type = models.CharField(_("Type"), choices=FIELD_CHOICES,
-        max_length=50)
+        max_length=55)
     required = models.BooleanField(_("Required"), default=True)
     visible = models.BooleanField(_("Visible"), default=True)
     choices = models.CharField(_("Choices"), max_length=1000, blank=True,
         help_text="Comma separated options where applicable")
     default = models.CharField(_("Default value"), blank=True, 
         max_length=FIELD_MAX_LENGTH)
+    help_text = models.CharField(_("Help text"), blank=True, max_length=100)
 
     objects = FieldManager()
 
